@@ -23,10 +23,8 @@
  * @stability: Stable
  * @include: tracker-sparql.h
  *
- * <para>
  * #TrackerSparqlCursor is an object which provides methods to iterate the
  * results of a query to the Tracker Store.
- * </para>
  */
 #include "config.h"
 
@@ -100,6 +98,21 @@ tracker_sparql_cursor_real_get_boolean (TrackerSparqlCursor *cursor,
 	return g_ascii_strcasecmp (text, "true") == 0;
 }
 
+static GDateTime *
+tracker_sparql_cursor_real_get_datetime (TrackerSparqlCursor *cursor,
+                                         gint                 column)
+{
+	const gchar *text;
+	GDateTime *date_time;
+
+	g_return_val_if_fail (tracker_sparql_cursor_real_is_bound (cursor, column), NULL);
+
+	text = tracker_sparql_cursor_get_string (cursor, column, NULL);
+	date_time = g_date_time_new_from_iso8601 (text, NULL);
+
+	return date_time;
+}
+
 static void
 tracker_sparql_cursor_finalize (GObject *object)
 {
@@ -164,6 +177,7 @@ tracker_sparql_cursor_class_init (TrackerSparqlCursorClass *klass)
 	klass->get_integer = tracker_sparql_cursor_real_get_integer;
 	klass->get_double = tracker_sparql_cursor_real_get_double;
 	klass->get_boolean = tracker_sparql_cursor_real_get_boolean;
+	klass->get_datetime = tracker_sparql_cursor_real_get_datetime;
 	klass->is_bound = tracker_sparql_cursor_real_is_bound;
 
 	/**
@@ -367,6 +381,26 @@ tracker_sparql_cursor_get_variable_name (TrackerSparqlCursor *cursor,
 	                                                                    column);
 }
 
+/**
+ * tracker_sparql_cursor_get_datetime:
+ * @cursor: a #TrackerSparqlCursor
+ * @column: column number to retrieve (first one is 0)
+ *
+ * Retrieve an GDateTime pointer for the current row in @column.
+ *
+ * Returns: (transfer full) (nullable): #GDateTime object, or %NULL if the given column does not contain a xsd:date or xsd:dateTime
+ * Since: 3.2
+ */
+GDateTime *
+tracker_sparql_cursor_get_datetime (TrackerSparqlCursor *cursor,
+                                    gint                 column)
+{
+	g_return_val_if_fail (TRACKER_IS_SPARQL_CURSOR (cursor), NULL);
+
+	return TRACKER_SPARQL_CURSOR_GET_CLASS (cursor)->get_datetime (cursor,
+	                                                               column);
+}
+
 /**
  * tracker_sparql_cursor_close:
  * @cursor: a #TrackerSparqlCursor
@@ -378,7 +412,7 @@ tracker_sparql_cursor_close (TrackerSparqlCursor *cursor)
 {
 	g_return_if_fail (TRACKER_IS_SPARQL_CURSOR (cursor));
 
-	return TRACKER_SPARQL_CURSOR_GET_CLASS (cursor)->close (cursor);
+	TRACKER_SPARQL_CURSOR_GET_CLASS (cursor)->close (cursor);
 }
 
 /**
@@ -451,10 +485,10 @@ tracker_sparql_cursor_next_async (TrackerSparqlCursor  *cursor,
 	g_return_if_fail (TRACKER_IS_SPARQL_CURSOR (cursor));
 	g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
 
-	return TRACKER_SPARQL_CURSOR_GET_CLASS (cursor)->next_async (cursor,
-	                                                             cancellable,
-	                                                             callback,
-	                                                             user_data);
+	TRACKER_SPARQL_CURSOR_GET_CLASS (cursor)->next_async (cursor,
+	                                                      cancellable,
+	                                                      callback,
+	                                                      user_data);
 }
 
 /**
@@ -500,5 +534,5 @@ tracker_sparql_cursor_rewind (TrackerSparqlCursor *cursor)
 {
 	g_return_if_fail (TRACKER_IS_SPARQL_CURSOR (cursor));
 
-	return TRACKER_SPARQL_CURSOR_GET_CLASS (cursor)->rewind (cursor);
+	TRACKER_SPARQL_CURSOR_GET_CLASS (cursor)->rewind (cursor);
 }
