@@ -19,6 +19,23 @@
  * Author: Carlos Garnacho <carlosg@gnome.org>
  */
 
+/**
+ * SECTION: tracker-endpoint-dbus
+ * @short_description: DBus endpoint
+ * @title: TrackerEndpointDBus
+ * @stability: Stable
+ * @include: libtracker-sparql/tracker-sparql.h
+ *
+ * #TrackerEndpointDBus is an endpoint implementation that exports
+ * a local #TrackerSparqlConnection so it is accessible in the given
+ * bus connection.
+ *
+ * Access to these endpoints may be transparently managed through
+ * the Tracker portal service for applications sandboxed via Flatpak, and
+ * access to data constrained to the graphs defined in the applications
+ * manifest.
+ */
+
 #include "config.h"
 
 #include "tracker-endpoint-dbus.h"
@@ -169,7 +186,7 @@ query_request_new (TrackerEndpointDBus   *endpoint,
 
 	stream = g_unix_output_stream_new (fd, TRUE);
 	buffered_stream = g_buffered_output_stream_new_sized (stream,
-	                                                      getpagesize ());
+	                                                      sysconf (_SC_PAGE_SIZE));
 
 	request->data_stream = g_data_output_stream_new (buffered_stream);
 	g_data_output_stream_set_byte_order (request->data_stream,
@@ -212,7 +229,7 @@ update_request_new (TrackerEndpointDBus   *endpoint,
 	stream = g_unix_input_stream_new (input, TRUE);
 	request->input_stream = g_data_input_stream_new (stream);
 	g_buffered_input_stream_set_buffer_size (G_BUFFERED_INPUT_STREAM (request->input_stream),
-	                                         getpagesize ());
+	                                         sysconf (_SC_PAGE_SIZE));
 	g_data_input_stream_set_byte_order (request->input_stream,
 	                                    G_DATA_STREAM_BYTE_ORDER_HOST_ENDIAN);
 	g_object_unref (stream);
@@ -725,7 +742,7 @@ notifier_events_cb (TrackerNotifier *notifier,
 	TrackerEndpointDBus *endpoint_dbus = user_data;
 	GVariantBuilder builder;
 	GError *error = NULL;
-	gint i;
+	guint i;
 
 	if (tracker_endpoint_dbus_filter_graph (endpoint_dbus, graph))
 		return;
