@@ -181,7 +181,8 @@ class PropertyRangeStringToDate (OntologyChangeTestTemplate):
     Change the range of a property from string to date. There shouldn't be any data loss.
     """
 
-    @ut.skip("Fails with: basic-future/91-test.ontology: Unsupported ontology change for http://example.org/ns#a_string: can't change rdfs:range (old=http://www.w3.org/2001/XMLSchema#dateTime, attempted new=http://www.w3.org/2001/XMLSchema#string)")
+    # Conversion from string to dateTime is not allowed
+    @ut.expectedFailure
     def test_property_range_string_to_date(self):
         self.template_test_ontology_change()
 
@@ -211,7 +212,8 @@ class PropertyRangeDateToString (OntologyChangeTestTemplate):
     Change the range of a property from date to string. There shouldn't be any data loss.
     """
 
-    @ut.skip("fails with: basic-future/91-test.ontology: Unsupported ontology change for http://example.org/ns#a_string: can't change rdfs:range (old=http://www.w3.org/2001/XMLSchema#dateTime, attempted new=http://www.w3.org/2001/XMLSchema#string)")
+    # Conversion from dateTime to string is not supported yet
+    @ut.expectedFailure
     def test_property_range_date_to_string(self):
         self.template_test_ontology_change()
 
@@ -240,7 +242,7 @@ class PropertyRangeIntToString (OntologyChangeTestTemplate):
     """
     Change the range of a property from int to string. There shouldn't be any data loss.
     """
-    @ut.skip("Fails with: Unable to insert multiple values for subject `http://example.org/ns#a_int' and single valued property `rdfs:comment' (old_value: 'This property is integer in basic here is string', new value: 'Property to test the changes string/int')")
+    
     def test_property_range_int_to_str(self):
         self.template_test_ontology_change()
 
@@ -269,7 +271,6 @@ class PropertyRangeStringToInt (OntologyChangeTestTemplate):
     Change the range of a property from string to int. There shouldn't be any data loss.
     """
 
-    @ut.skip("Fails with: Unable to insert multiple values for subject `http://example.org/ns#a_int' and single valued property `rdfs:comment' (old_value: 'Property to test the changes string/int', new value: 'This property is integer in basic here is string')")
     def test_property_range_str_to_int(self):
         self.template_test_ontology_change()
 
@@ -573,7 +574,7 @@ class OntologyAddPropertyTest (OntologyChangeTestTemplate):
     """
     Add new properties in the ontology, with/without super prop and different ranges and cardinalities
     """
-    @ut.skip("Fails with:Unable to insert multiple values for subject `http://example.org/ns#a_int' and single valued property `rdfs:comment' (old_value: 'This property is integer in basic here is string', new value: 'Property to test the changes string/int')")
+    
     def test_ontology_add_property(self):
         self.template_test_ontology_change()
 
@@ -668,7 +669,7 @@ class DomainIndexAddTest (OntologyChangeTestTemplate):
     """
     Add nrl:domainIndex to a class and check there is no data loss.
     """
-    @ut.skip("Fails with: basic-future/91-test.ontology: Unsupported ontology change for test:b_property: can't change rdfs:domain (old=test:A, attempted new=test:B) ")
+    
     def test_domain_index_add(self):
         self.template_test_ontology_change()
 
@@ -758,7 +759,9 @@ class SuperclassRemovalTest (OntologyChangeTestTemplate):
     """
     Remove the superclass relation between two classes
     """
-    @ut.skip("Fails with: Unsupported ontology change for http://example.org/ns#B: can't change rdfs:subClassOf (old=-, attempted new=-)")
+
+    # Changes to rdfs:subClassOf are not allowed
+    @ut.expectedFailure
     def test_superclass_removal(self):
         self.template_test_ontology_change()
 
@@ -801,7 +804,9 @@ class SuperclassAdditionTest (OntologyChangeTestTemplate):
     """
     Add a superclass to a class with no superclass previously
     """
-    @ut.skip("Fails with: basic-future/91-test.ontology: Unsupported ontology change for test:B: can't change rdfs:subClassOf (old=-, attempted new=test:A)")
+
+    # Changes to rdfs:subClassOf are not allowed
+    @ut.expectedFailure
     def test_superclass_addition(self):
         self.template_test_ontology_change()
 
@@ -844,7 +849,9 @@ class PropertyPromotionTest (OntologyChangeTestTemplate):
     """
     Move a property to the superclass
     """
-    @ut.skip("Fails with: basic-future/91-test.ontology: Unsupported ontology change for test:b_property: can't change rdfs:domain (old=test:A, attempted new=test:B)")
+
+    # Changes to rdfs:domain are not allowed
+    @ut.expectedFailure
     def test_property_promotion(self):
         self.template_test_ontology_change()
 
@@ -880,7 +887,9 @@ class PropertyRelegationTest (OntologyChangeTestTemplate):
     """
     Move a property to the subclass
     """
-    @ut.skip("Fails")
+
+    # Changes to rdfs:domain are not allowed
+    @ut.expectedFailure
     def test_property_relegation(self):
         self.template_test_ontology_change()
 
